@@ -1047,7 +1047,7 @@ class SoSReport(SoSComponent):
             self.ui_log.info(_("The following plugins are currently enabled:"))
             self.ui_log.info("")
             for (plugname, plug) in self.loaded_plugins:
-                self.ui_log.info(f" {plugname:<20} {plug.get_description()}")
+                self.ui_log.info(f" {plugname:<30} {plug.get_description()}")
         else:
             self.ui_log.info(_("No plugin enabled."))
         self.ui_log.info("")
@@ -1098,7 +1098,7 @@ class SoSReport(SoSComponent):
                 if tmpopt is None:
                     tmpopt = 0
 
-                self.ui_log.info(f" {f'{opt.plugin}.{opt.name}':<35} "
+                self.ui_log.info(f" {f'{opt.plugin}.{opt.name}':<40} "
                                  f"{tmpopt:<15} {opt.desc}")
         else:
             self.ui_log.info(_("No plugin options available."))
@@ -1880,9 +1880,10 @@ class SoSReport(SoSComponent):
             if not self.opts.no_report:
                 self.generate_reports()
             if not self.opts.no_postproc:
+                self.ui_log.info('Starting post-processing of collected data')
                 self.postproc()
             else:
-                self.ui_log.info("Skipping postprocessing of collected data")
+                self.ui_log.info("Skipping post-processing of collected data")
             self.version()
             return self.final_work()
 
